@@ -66,6 +66,11 @@ unique.yearweek <- function(x, incomparables = FALSE, ...) {
   as_yearweek(NextMethod())
 }
 
+#' @export
+yearweek.default <- function(x) {
+  dont_know(x, "yearweek")
+}
+
 #' @export
 yearweek.POSIXt <- function(x) {
   as_yearweek(as_date(lubridate::floor_date(x, unit = "weeks", week_start = 1)))
@@ -144,6 +149,11 @@ unique.yearmonth <- function(x, incomparables = FALSE, ...) {
   as_yearmonth(NextMethod())
 }
 
+#' @export
+yearmonth.default <- function(x) {
+  dont_know(x, "yearmonth")
+}
+
 #' @export
 yearmonth.POSIXt <- function(x) {
   as_yearmonth(as_date(lubridate::floor_date(x, unit = "months")))
@@ -218,6 +228,11 @@ unique.yearquarter <- function(x, incomparables = FALSE, ...) {
   as_yearquarter(NextMethod())
 }
 
+#' @export
+yearquarter.default <- function(x) {
+  dont_know(x, "yearquarter")
+}
+
 #' @export
 yearquarter.POSIXt <- function(x) {
   as_yearquarter(as_date(lubridate::floor_date(x, unit = "quarters")))
