@@ -18,7 +18,8 @@ type_sum.yearquarter <- function(x) {
   "qtr"
 }
 
-key_header <- function(x) {
+#' @export
+tbl_sum.tbl_ts <- function(x) {
   int_x <- interval(x)
   fnt_int <- format(int_x)
   first <- c("A tsibble" = paste(dim_tbl_ts(x), surround(fnt_int, "[")))
@@ -32,31 +33,32 @@ key_header <- function(x) {
   )
 }
 
-#' @export
-tbl_sum.tbl_ts <- function(x) {
-  result <- key_header(x)
-  idx2 <- index2(x)
-  if (!identical(index(x), idx2)) {
-    idx_suffix <- paste("@", quo_text(idx2))
-    result <- c(result, "Groups" = idx_suffix)
-  }
-  result
-}
-
 #' @export
 tbl_sum.grouped_ts <- function(x) {
-  result <- key_header(x)
   n_grps <- big_mark(n_groups(x))
   if (has_length(n_grps, 0)) {
     n_grps <- "?"
   }
-  grps <- paste(paste_comma(group_vars(x)), surround(n_grps, "["))
-  idx2 <- index2(x)
-  if (identical(index(x), idx2)) {
-    return(c(result, "Groups" = grps))
+  grps <- group_vars(x)
+  idx2 <- quo_name(index2(x))
+  grp_var <- setdiff(grps, idx2)
+  idx_suffix <- paste("@", idx2)
+  if (is_empty(grp_var)) {
+    return(c(
+      NextMethod(), 
+      "Groups" = paste(idx_suffix, surround(n_grps, "["))
+    ))
+  } else if (has_length(grps, length(grp_var))) {
+    return(c(
+      NextMethod(), 
+      "Groups" = paste(paste_comma(grp_var), surround(n_grps, "["))
+    ))
+  } else {
+    return(c(
+      NextMethod(), 
+      "Groups" = paste(paste_comma(grp_var), idx_suffix, surround(n_grps, "["))
+    ))
   }
-  idx_suffix <- paste("@", quo_text(idx2))
-  c(result, "Groups" = paste(grps, idx_suffix))
 }
 
 
