@@ -64,3 +64,11 @@ min0 <- function(x) {
 max0 <- function(x) {
   max(x, na.rm = TRUE)
 }
+
+dont_know <- function(x, FUN) {
+  cls <- class(x)[1]
+  msg <- sprintf(
+    "`%s()` doesn't know how to coerce the `%s` class yet.", FUN, cls
+  )
+  abort(msg)
+}
