@@ -26,6 +26,10 @@ test_that("some S3 methods for yearweek, yearmonth & yearquarter", {
   expect_is(y[1:2], "yearquarter")
 })
 
+test_that("unsupported class for index functions", {
+  expect_error(yearweek(seq(2010, 2012, by = 1 / 52)), "coerce the `numeric`")
+})
+
 xx <- make_datetime(2018, 1, 1, 0)
 
 test_that("POSIXct", {
