@@ -1,4 +1,4 @@
-context("Dplyr join family in tsibble")
+context("dplyr join family in tsibble")
 
 x <- tsibble(
   year = rep(2016:2017, 2), grp = rep(letters[1:2], each = 2),
@@ -9,7 +9,7 @@ y_key <- tibble(grp = "a", upper = "A")
 y_idx <- tibble(year = 2018, x = "fun")
 z <- tibble(grp = c("a", "b"), upper = c("A", "B"))
 
-test_that("left_join", {
+test_that("left_join()", {
   left <- x %>% left_join(y_key)
   expect_is(left, "tbl_ts")
   expect_equal(dim(left), c(4, 3))
@@ -17,7 +17,7 @@ test_that("left_join", {
   expect_identical(index(x), index(left))
 })
 
-test_that("right_join", {
+test_that("right_join()", {
   right <- x %>% right_join(y_key)
   expect_is(right, "tbl_ts")
   expect_equal(dim(right), c(2, 3))
@@ -30,7 +30,7 @@ test_that("right_join", {
   expect_equal(group_size(grped_right), 2)
 })
 
-test_that("full_join", {
+test_that("full_join()", {
   full <- x %>% full_join(y_idx)
   expect_is(full, "tbl_ts")
   expect_equal(dim(full), c(5, 3))
@@ -38,7 +38,7 @@ test_that("full_join", {
   expect_identical(index(x), index(full))
 })
 
-test_that("inner_join", {
+test_that("inner_join()", {
   inner <- x %>% inner_join(y_key)
   expect_is(inner, "tbl_ts")
   expect_equal(dim(inner), c(2, 3))
@@ -46,7 +46,7 @@ test_that("inner_join", {
   expect_identical(index(x), index(inner))
 })
 
-test_that("semi_join", {
+test_that("semi_join()", {
   semi <- x %>% semi_join(y_key)
   expect_is(semi, "tbl_ts")
   expect_equal(dim(semi), c(2, 2))
@@ -54,7 +54,7 @@ test_that("semi_join", {
   expect_identical(index(x), index(semi))
 })
 
-test_that("anti_join", {
+test_that("anti_join()", {
   anti <- x %>% anti_join(y_key)
   expect_is(anti, "tbl_ts")
   expect_equal(dim(anti), c(2, 2))
