@@ -35,7 +35,7 @@ test_that("tbl_sum.tbl_ts()", {
   expect_identical(tbl_sum(tbl1), c("A tsibble" = "10 x 2 [1DAY]"))
   expect_identical(
     tbl_sum(tbl1 %>% index_by(yrmth = yearmonth(date))),
-    c("A tsibble" = "10 x 3 [1DAY]", "Groups" = "@ yrmth")
+    c("A tsibble" = "10 x 3 [1DAY]", "Groups" = "@ yrmth [1]")
   )
   expect_identical(
     tbl_sum(tbl2),
@@ -46,7 +46,7 @@ test_that("tbl_sum.tbl_ts()", {
     c(
       "A tsibble" = "30 x 4 [1QUARTER]",
       "Keys" = "group [3]",
-      "Groups" = "@ year"
+      "Groups" = "@ year [3]"
     )
   )
 })
@@ -65,7 +65,7 @@ test_that("tbl_sum.grouped_ts()", {
     c(
       "A tsibble" = "30 x 4 [1QUARTER]",
       "Keys" = "group [3]",
-      "Groups" = "group [3] @ year"
+      "Groups" = "group @ year [9]"
     )
   )
 })
