@@ -38,8 +38,7 @@ test_that("POSIXt with 1 second interval", {
   expect_is(index(tsbl), "name")
   expect_identical(quo_text(index(tsbl)), "date_time")
   expect_identical(time_unit(tsbl$date_time), 1)
-  expect_identical(format(key(tsbl)), "NULL")
-  expect_output(print(key(tsbl)), "NULL")
+  expect_identical(format(key(tsbl)), list())
   expect_identical(format(groups(tsbl)), "NULL")
   expect_identical(format(interval(tsbl)), "1SECOND")
   expect_output(print(interval(tsbl)), "1SECOND")
