@@ -35,10 +35,11 @@ test_that("a tsibble with a single key", {
 
 test_that("a tsibble with more than one measured vars", {
   expect_error(as.ts(pedestrian), "Can't determine the `value`:")
-  expect_error(as.ts(pedestrian, value = Date_Time), "Can't determine the `value`:")
+  expect_error(as.ts(pedestrian, value = Date_Time), "`value` must be one of them:")
   y <- as.ts(pedestrian, value = Count)
   expect_is(y, "mts")
   expect_equal(frequency(y), 24)
+  expect_equal(frequency(pedestrian), 24)
   expect_equal(ncol(y), 4)
 })
 
